@@ -1,6 +1,4 @@
 /***************************************************************************
- *   ctdow.cpp                                                             *
- *   --------------------------------------------------------------------  *
  *   CT Day Of Week Implementation                                         *
  *   --------------------------------------------------------------------  *
  *   Copyright (C) 1999, Gary Meyer <gary@meyer.net>                       *
@@ -72,7 +70,7 @@ string CTDayOfWeek::getName(const int ndx, const bool format)
 
 void CTDayOfWeek::initializeNames()
 {
-  if (shortName[1] == "")
+  if (shortName[1].empty())
   {
     const string shortDOWName[8] =
     {
