@@ -33,8 +33,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -45,6 +45,7 @@
 #define PACKAGEINFO_H
 #include "../config.h"
 
+#include <qmap.h>
 #include <qdict.h>
 #include <qstring.h>
 #include <qpixmap.h>
@@ -60,11 +61,11 @@ class KpTreeList;
 class packageInfo
 {
 public:
-  packageInfo(QDict<QString> *_info, pkgInterface *type);
+  packageInfo(QMap<QString, QString> _info, pkgInterface *type);
   // Constructor: create a packageInfo object using the property
   // dictionary from _info
 
-  packageInfo(QDict<QString> *_info, const QString &_filename);
+  packageInfo(QMap<QString, QString> _info, const QString &_filename);
   // Constructor: same as above, but also sets filename to _filename.
   // This is used in the case that the package info was obtained from
   // an uninstalled package.
@@ -93,9 +94,6 @@ public:
   // returns the treelist item object for this package or
   // NULL if the object hasn't been placed
 
-  QDict<QString> *getDict();
-  // returns the property dictionary for the package
-
   void setFilename(const QString &f);
 
   QString getUrl();
@@ -125,7 +123,7 @@ public:
 	      bool infoPackage = FALSE);
   // insert packgeInfo either installed or not installed
 
-  QDict<QString> *info;
+  QMap<QString, QString> info;
   // This stores the property dictionary of the package
 
   KpTreeListItem *item;
