@@ -1,6 +1,4 @@
 /***************************************************************************
-                          kdltooltip.h  -  description
-                             -------------------
     begin                : Tue Oct 5 1999
     copyright            : (C) 1999 by Peter Putzer
     email                : putzer@kde.org
